AsyncServiceChainBuilder

Struct AsyncServiceChainBuilder 

pub struct AsyncServiceChainBuilder<P: AsyncService, S: AsyncService<Input = P::Output>> { /* private fields */ }
Returned by ServiceChain::start_async to build an async service chain. Use the next(self, AsyncService) function to append more services to the ServiceChain. Use the end(self) function to finish building and return the resulting ServiceChain.

Implementations

Source

impl<P: AsyncService + Send + Sync, S: AsyncService<Input = P::Output> + Send + Sync> AsyncServiceChainBuilder<P, S>
where P::Error: Debug + Send, S::Error: Debug + Send, P::Output: Send, S::Output: Send,

pub fn next<NS: AsyncService<Input = S::Output>>( self, service: NS, ) -> AsyncServiceChainBuilder<ServiceChain<P, S>, NS>

Append another AsyncService to the end of the service chain.

Source

impl<P: AsyncService + Send + Sync, S: AsyncService<Input = P::Output> + Send + Sync> AsyncServiceChainBuilder<P, S>
where P::Error: Debug + Send, S::Error: Debug + Send, P::Output: Send, S::Output: Send + Clone + Sync,

pub fn fork_clone<NS1: AsyncService<Input = S::Output> + Send + Sync, NS2: AsyncService<Input = S::Output, Error = NS1::Error> + Send + Sync>( self, first: NS1, second: NS2, ) -> AsyncServiceChainBuilder<ServiceChain<P, S>, CloningForkService<NS1, NS2>>
where <NS1 as AsyncService>::Output: Send + Sync, <NS2 as AsyncService>::Output: Send + Sync,

Fork the service chain to the given two services by cloning the input.

Source

impl<'a, P: AsyncService + Send + Sync + 'a, S: AsyncService<Input = P::Output> + Send + Sync + 'a> AsyncServiceChainBuilder<P, S>
where P::Error: Send + Debug + 'static, S::Error: Send + Debug + 'static, P::Output: Send + 'a, S::Output: Send + 'a,

pub fn end(self) -> ServiceChain<P, S>

End and return the resulting ServiceChain.