CloningForkService

Struct CloningForkService 

pub struct CloningForkService<S1, S2> { /* private fields */ }
A Service, MutService, or AsyncService that encapsulates two service and accepts a Cloneable input, which is passed to both underlying services, returning their outputs as a tuple.

Implementations

Source

impl<S1, S2> CloningForkService<S1, S2>

pub fn new(first: S1, second: S2) -> Self