DynService

Struct DynService 

pub struct DynService<'a, I, O, E> { /* private fields */ }
A Service which encapsulates a Box<dyn Service<...>>.

This is useful when you have a Service with a complicated compile-time type that needs to be passed to a function with a simplified signature.

Implementations

Source

impl<'a, I, O, E> DynService<'a, I, O, E>

pub fn new<S: Service<Input = I, Output = O, Error = E> + 'a>( service: S, ) -> Self