PollService

Struct PollService 

pub struct PollService<E, S, F>
where F: Fn(usize) -> Result<(), RetryError<E>>,
{ /* private fields */ }
A Service, MutService, or AsyncService, which encapsulates a Service<(), Output = Option<T>>, MutService<(), Output = Option<T>>, or AsyncService<(), Output = Option<T>>, blocking with the given idle function until a value is returned or the idle function returns an error.

When the underlying Service<()> returns None, the given idle function will be called. The idle function will be called repeatedly, given the attempt number as input, until Some(T) is returned by the underlying service. The idle function may return Err(RetryError::Interrupted) to return an error and avoid blocking forever.

See the idle module for some provided idle functions.

Implementations

Source

impl<E, S, F> PollService<E, S, F>
where F: Fn(usize) -> Result<(), RetryError<E>>,

pub fn new(service: S, idle: F) -> Self