Struct sod::RefForkService

source ·
pub struct RefForkService<I, S1, S2> { /* private fields */ }
A Service, MutService, or AsyncService that encapsulates two service and accepts a input as a reference, which is passed to both underlying services, returning their outputs as a tuple.

Implementations

source

impl<I, S1, S2> RefForkService<I, S1, S2>

source

pub fn new(first: S1, second: S2) -> Self