pub struct CloningForkService<S1, S2> { /* private fields */ }Expand description
A Service, MutService, or AsyncService that encapsulates two service and accepts a Cloneable input, which is passed to both underlying services, returning their outputs as a tuple.
Implementations
Sourceimpl<S1, S2> CloningForkService<S1, S2>
impl<S1, S2> CloningForkService<S1, S2>