Struct sod::ServiceMut
source · pub struct ServiceMut<I, S> { /* private fields */ }Expand description
A MutService that encapsulates an underlying Service, exposing it as mut.
Any Service should be able to be represented as a MutService which simply does not mutate itself.
Implementations